crikit.io.lazy5.ui package — CRIKit2 0.4.3 documentation

# crikit.io.lazy5.ui package

## Submodules

## crikit.io.lazy5.ui.QtHdfLoad module

### HDF5 LOAD DATA QDialog (crikit.vis.subguis.h5loadgui)

> H5LoadGUI : A graphical user interface (GUI) to select HDF5 dataset(s)

> Method : H5LoadGUI.getFileDataSets()

> Return (tuple) : (path [str], filename [str], dataset(s) [list], selection_made [bool])

> Methods that interact with Qt follow the Qt naming convention: firstSecondThird

class crikit.io.lazy5.ui.QtHdfLoad.HdfLoad(title=None, parent=None)

  Bases: `PyQt5.QtWidgets.QDialog`

  GUI Loader Class for H5 Files

  config = {'attr_description': 'Memo', 'excl_filtering': True, 'only_show_grp_w_dset': True}
  dataGroupChange()

    Action : ComboBox containing Groups with DataSets has changed

  datasetSelected()

    Action : One or more DataSets were selected from the list

  fileOpen(pth='./', title=None)

    Select HDF5 File via QDialog built-in.

  filterDatasets()

    Filter list of datasets based on include and exclude strings

  static getFileDataSets(pth='./', title=None, parent=None)

    Retrieve the filename and datasets selected by the user (via GUI)

    Parameters

      pth (str) – Home directory to start in OR the relative pth to a file

    Return type

      Tuple (str, str, list[str]) as (path, filename, [dataset(s)])

  populateGroups()

    Populate dropdown box of group ui.comboBoxGroupSelect

  populate_attrs(attr_dict=None)

    Populate attribute and memo boxes for currently selected dataset

## crikit.io.lazy5.ui.qt_HdfLoad module

class crikit.io.lazy5.ui.qt_HdfLoad.Ui_Dialog

  Bases: `object`

  retranslateUi(Dialog)
  setupUi(Dialog)

## Module contents